Class: ArGallery

Inherits:
ApplicationRecord
  • Object
show all
Defined in:
app/models/ar_gallery.rb

Overview

ArGallery model holds data for picture galleries for various types of documents. Picture Gallery can be added to any document, provided that it has two parameters: doc_id and doc_type.

Schema information

Table name: ar_gallery : Pictures gallery

id Integer id doc_id Integer Parent document id where this gallery lies doc_type String Parent document table name title String Title name for picture description String Short description picture String Picture filename thumbnail String Picture thumbnail order Integer Order of picture in a gallery

active Boolean Picture is active created_by Integer created_by updated_by Integer updated_by created_at Time created_at updated_at Time updated_at