Class: ArLink

Inherits:
ApplicationRecord
  • Object
show all
Defined in:
app/models/ar_link.rb

Overview

Schema information

Table name: ar_link : Alternative links

id Integer id created_at Time created_at updated_at Time updated_at name String Link name ex. homepage params String Aditional parameters passed to document renderer active Boolean Link is active page_id Integer Page redirected to by this shortcut link redirect String Link to redirect to created_by Integer created_by updated_by Integer updated_by ar_site_id Object Link is valid for site

ArLink documents is used for creating alternative url links or redirections. page_id field must point to valid ArPage document which will be used for further processing.