Class: ArPollItem

Inherits:
ApplicationRecord
  • Object
show all
Defined in:
app/models/ar_poll_item.rb

Overview

Schema information

Table name: ar_poll_item : Poll items define entry fields on poll questionary and formulars.

id Integer id created_at Time created_at updated_at Time updated_at name String Name (alias) of returned field name text String Caption of item field_type String Input field type size String size mandatory Boolean Item entry is mandatory separator String Separator between items options String Options for the item. Depends on item type. order Integer Order of item on poll active Boolean Item is active