Class: ArUser

Inherits:
ApplicationRecord
  • Object
show all
Includes:
ArUserConcern
Defined in:
app/models/ar_user.rb

Overview

Schema information

Table name: ar_user : Users

id Integer id created_at Time created_at updated_at Time updated_at username String Username title String Title (dr, mag) first_name String Users first name middle_name String Middle name last_name String Users last name name String Name colected from firstname, title and lastname company String company address String Home address post String Post and post city country String Country phone String Phone number email String e-Mail address www String www picture String Picture file name birthdate Date Date of birth about String Short description of user last_visit Time Users last visit active Boolean Account is active valid_from Date Account is valid from valid_to Date Account is valid until created_by Integer created_by updated_by Integer Account last updated by type Integer Type of user account signature String signature interests String interests job_occup String job_occup description String description reg_date Date reg_date password_digest String password_digest ar_user_roles Embedded: ArUserRole Roles for this user

ar_users table holds data about regitered users. Passwords are encrypted with bcrypt gem.

This model defines basic fields required for evidence of registerred users. Since it is implemented as ActiveSupport::Concern you are encouraged to further expand model with your own data structures.