Class: ArJournal
- Inherits:
-
ApplicationRecord
- Object
- ApplicationRecord
- ArJournal
- Defined in:
- app/models/ar_journal.rb
Overview
Schema information
Table name: ar_journal : Update journal
id Integer id user_id Integer User site_id Integer Site doc_id Integer doc_id operation String Operation tables String Table name ids String Parent ids ip String ip address from where operation was performed time DateTime Time of operation diff String Differences
ar_journals collections saves all data that has been updated through agile controller. It saves old and new values of changed fields and can be used for instant restore of single document field or tracking who and when updated particular document.