Class: ArUserGroup
- Inherits:
-
ApplicationRecord
- Object
- ApplicationRecord
- ArUserGroup
- Defined in:
- app/models/ar_user_group.rb
Overview
Schema information
Table name: ar_user_group: When user is a member of group of users
id Integer id ar_user_id Integer User id group_id Integer Group id
ArUserGroup record holds relation of which group specific user is a member. Groups are like users defined in ArUser table and have group flag set to true.